#
# spec file for package mupdf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mupdf
Version:        1.12.0
Release:        23.1
Summary:        Lightweight PDF and XPS Viewer and Parser and Rendering Library
License:        AGPL-3.0+
Group:          Productivity/Office/Other
Url:            https://mupdf.com/
Source0:        https://mupdf.com/downloads/mupdf-%{version}-source.tar.xz#/%{name}-%{version}.tar.xz
Source1:        mupdf.desktop
Source2:        mupdf.png
Patch1:         fix-openjpeg-flags.patch
Patch2:         CVE-2018-5686.patch
Patch3:         CVE-2017-17858.patch
BuildRequires:  freetype-devel
BuildRequires:  gcc-c++
BuildRequires:  jbig2dec-devel
BuildRequires:  libcurl-devel
BuildRequires:  libjpeg-devel
BuildRequires:  openjpeg2-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(harfbuzz)
Requires:       xdg-utils

%description
MuPDF is a lightweight PDF and XPS viewer and parser/rendering library.

The renderer in MuPDF is tailored for high quality anti-aliased graphics. It
renders text with metrics and spacing accurate to within fractions of a pixel
for the highest fidelity in reproducing the look of a printed page on screen.

MuPDF is also small, fast, and yet complete. It supports PDF 1.7 with
transparency, encryption, hyperlinks, annotations, search and many other bells
and whistles. MuPDF can also read XPS documents (OpenXPS/ECMA-388).

%package devel-static
Summary:        Development Files for mupdf
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel-static
This package contains development files needed for developing applications
based on mupdf.

%prep
%setup -q -n %{name}-%{version}-source
%patch1 -p1
%patch2 -p1
%patch3 -p1

# do not use the inlined copies of build dpendencies except for mujs
rm -rf $(ls -d thirdparty/*/ | grep -v mujs)

for src in docs/*.c; do
    if [ -r "$src" ]; then
        ln -s "$src" "docs/examples/${src##*/}"
    fi
done

sed -e s,'INSTALL_APPS := .*','INSTALL_APPS := $(MUTOOL_EXE) $(MUVIEW_X11_CURL_EXE)', \
    -e '/^INSTALL_APPS +=/d' -i Makefile

%build
# do no set CFLAGS which is used by the build system itself!
export XCFLAGS="%{optflags} -fPIC -lpthread"
make %{?_smp_mflags} \
    build=release \
    verbose=yes \
    NOCURL= \
    CURL_CFLAGS="$(pkg-config --libs libcurl)" \
    CURL_LIBS=" -pthread $(pkg-config --libs libcurl)" \
    HAVE_GLFW=no

%install
%make_install build=release prefix=%{_prefix} libdir=%{_libdir}

mv %{buildroot}%{_bindir}/mupdf-x11-curl %{buildroot}%{_bindir}/mupdf

rm -rf %{buildroot}%{_datadir}/doc/

chmod 0644 %{buildroot}%{_includedir}/mupdf/*.h \
    %{buildroot}%{_includedir}/mupdf/*/*.h \
    %{buildroot}%{_libdir}/*.a \
    %{buildroot}%{_mandir}/man1/*

install -D -p -m 644 %{SOURCE1} \
    %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -p -m 644 %{SOURCE2} \
    %{buildroot}%{_datadir}/pixmaps/%{name}.png

%suse_update_desktop_file mupdf

%if 0%{?suse_version} <= 1320
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%doc CHANGES COPYING README 
%doc docs/examples/
%{_bindir}/mupdf
%{_bindir}/mutool
%{_datadir}/applications/mupdf.desktop
%{_datadir}/pixmaps/mupdf.png
%{_mandir}/man1/mupdf.1%{ext_man}
%{_mandir}/man1/mutool.1%{ext_man}

%files devel-static
%{_includedir}/mupdf/
%{_libdir}/libmupdf.a
%{_libdir}/libmupdfthird.a

%changelog
* Tue Jan 23 2018 kbabioch@suse.com
- Add CVE-2017-17858.patch to fix an heap-based buffer overflow
  CVE-2017-17858 bsc#1077161
* Mon Jan 22 2018 idonmez@suse.com
- Add CVE-2018-5686.patch to fix an infinite loop
  CVE-2018-5686 bsc#1075936
* Sun Jan 14 2018 avindra@opensuse.org
- Update to version 1.12.0
  * Color Management:
    + LCMS2 library for color management
    + CMYK rendering with overprint simulation
    + Spot color rendering
    + Transparency rendering fixes
  * Structured text output improvements:
    + Reworked structured text API
    + Faster text searching
    + Highlight and copy text by selecting lines instead of by
    area
    + New semantic XHTML output format
    + New layout preserving HTML output format
  * Features and improvements:
    + Improved non-AA rendering with new scan converter
    + Improved LARGEFILE support
    + Improved TIFF support
    + Improved documentation
    + PCLm output.
    + PSD output.
    + New "mutool trace" tool.
    + New "mutool sign" tool (work in progress).
    + Text redaction (work in progress).
    + Lots of bug fixes.
- Strip "-source" from tarball name
- Switch to xz release (13mb smaller)
- rebase fix-openjpeg-flags.patch
- drop reproducible.patch
  * fixed upstream in 081d4c72430e3077a05499c783d9fbe24361b368
- Fixes CVE-2017-15369 (bsc#1063413), CVE-2017-15587 (bsc#1064027)
* Fri Nov 10 2017 aloisio@gmx.com
- Update to version 1.11
  * This is primarily a bug fix release.
  * PDF portfolio support with command line tool "mutool
    portfolio".
  * Add callbacks to load fallback fonts from the system.
  * Use system fonts in Android to reduce install size.
  * Flag to disable publisher styles in EPUB layout.
  * Improved SVG output.
- Refreshed fix-openjpeg-flags.patch and reproducible.patch
- Dropped CVE-2017-5896.patch, bsc1023760.patch,
  CVE-2016-10221.patch, CVE-2016-8728.patch, CVE-2017-7976.patch,
  CVE-2016-10132.patch, CVE-2016-10133.patch,
  CVE-2016-10141.patch, CVE-2017-5627.patch
  and CVE-2017-5628.patch (merged or adapted upstream)
* Thu Aug  3 2017 idonmez@suse.com
- Add CVE-2016-10221.patch, CVE-2016-8728.patch and
  CVE-2017-7976.patch to fix CVE-2016-10221, CVE-2016-8728,
  CVE-2016-8729 and CVE-2017-7976
  bsc#1032140 bsc#1039850 bsc#1052029
* Mon May 29 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
* Thu Apr 27 2017 idonmez@suse.com
- mupdf is not a terminal app boo#1036637
* Fri Feb 10 2017 idonmez@suse.com
- Add bsc1023760.patch to fix writing svg output to stdout if no
  output specified bsc#1023760
* Fri Feb 10 2017 idonmez@suse.com
- Add CVE-2017-5896.patch to fix a heap overflow
  CVE-2017-5896 bsc#1023761 bsc#1024679
* Mon Feb  6 2017 idonmez@suse.com
- Add CVE-2017-5627.patch and CVE-2017-5628.patch fixes
  CVE-2017-5627 and CVE-2017-5628 bsc#1022503 bsc#1022504
* Tue Jan 24 2017 idonmez@suse.com
- Add CVE-2016-10132.patch, CVE-2016-10133.patch and
  CVE-2016-10141.patch to fix CVE-2016-10132, CVE-2016-10133 and
  CVE-2016-10141 bsc#1019877
* Tue Dec 20 2016 idonmez@suse.com
- Update to version 1.10a
  * A bug with mutool and saving PDF files using the 'ascii'
    option has been fixed.
- Add fix-openjpeg-flags.patch to stop defining OPJ_STATIC,
  this is https://github.com/uclouvain/openjpeg/issues/802
* Thu Nov 24 2016 idonmez@suse.com
- Update to version 1.10
  * FictionBook (FB2) e-book support.
  * Simple SVG parser (a small subset of SVG only).
  * mutool convert: a new document conversion tool and interface.
  * Multi-threaded rendering in mudraw.
  * Updated base 14 fonts from URW.
  * New CJK font with language specific variants.
  * Hyperlink support in EPUB.
  * Alpha channel is now optional in pixmaps.
  * More aggressive purging of cached objects.
  * Partial image decoding for lower memory use when banding.
  * Reduced default set of built-in CMap tables to the minimum required.
  * FZ_ENABLE_PDF, _XPS, _JS, to disable features at compile time.
  * Function level linking.
  * Dropped pdf object generation numbers from public interfaces.
  * Simplified PDF page, xobject, and annotation internals.
  * Closing and freeing devices and writers are now separate steps.
  * Improved PDF annotation editing interface (still a work in progress).
  * Document writer interface.
  * Banded image writer interface.
- Drop CVE-2016-6265.patch and mupdf-fix-openjpeg2.patch,
  both are fixed upstream.
* Fri Jul 22 2016 idonmez@suse.com
- Add CVE-2016-6265.patch to fix a use-after-free bsc#990195
* Fri Apr 22 2016 idonmez@suse.com
- Update to version 1.9a
  * Fix a regression in text extraction.
* Tue Apr 19 2016 idonmez@suse.com
- Update to version 1.9
  * Bidirectional layout for Arabic and Hebrew scripts.
  * Shaping complex scripts for EPUB text layout.
  * Noto fallback fonts for EPUB layout.
  * mutool create:
  - Create new PDF files from scratch.
  - Read an annotated content stream in a text file and write a
    PDF file, automatically embedding font and image resources.
  * mutool run:
  - Run javascript scripts with MuPDF bindings.
  - The interface is similar to the new Java interface.
  * mutool draw:
  - Optional multi-threaded operation (Windows and pthreads).
  - Optional low memory mode (primarily for testing).
* Mon Mar 21 2016 idonmez@suse.com
- Set to best anti-alias mode (8) by default.
* Thu Nov 19 2015 idonmez@suse.com
- Ship mupdf-x11-curl as default mupdf. Drop non-curl version.
- Drop mujstest as it seems to be a test utility.
* Thu Nov 12 2015 idonmez@suse.com
- Update to version 1.8
  * New URW fonts with greek and cyrillic.
  * 64-bit file support.
  * Updated FreeType to version 2.6.1.
  * Various font substitution bug fixes.
  * Fix setjmp/longjmp behaviour which could cause optimizing
    compilers to misbehave.
  * EPUB improvements: User style sheets, GIF images, Table of Contents,
    CJK text, Page margins and many bug fixes.
* Tue Aug 18 2015 idonmez@suse.com
- Update to version 1.7a
  * Bug fixes:
    + Fixed bug that allocated too much memory when packing paths.
    + Fixed EPUB font scaling bug.
    + Fixed EPUB file type handling in viewers.
    + Improved tolerance for broken and unsupported CSS.
  * New features:
    + Added -z option to mutool clean.
* Sun Apr 19 2015 aloisio@gmx.com
- Update to version 1.7
  Headline changes:
  * New 'Indie dev' licensing options - contact sales@artifex.com
    for more details.
  * New HTML layout engine, and (DRM-free) EPUB viewer.
  * Reduced memory usage - displaylists and internal PDF
    representation take much less memory, reducing total memory
    use on some files by over 60%%.
  Important API changes:
  * Bound contexts have been removed; we now pass fz_contexts
    explicitly.
  * Reference counting of paths and text structures.
  Features:
  * Add mutool pages option.
  * Tweaked rendering to prevent feature dropout in common cases.
  * Viewer tweaks
  * Better mouse wheel handling
  * Shift-space support
  * Mouse button control of presentation mode
  Internal changes:
  * Removal of bound contexts; fz_contexts now passed explicitly
    everywhere.
  * PDF filter revamp - simpler interface.
  * Devices use derived structures rather than user pointer.
  * Sparse PDF xrefs held in more compact form.
  * New gsview viewer split out to its own repository.
  Bug fixes:
  * Improved handling of broken files.
  * Fix BBoxes of Type 3 fonts.
  * Updated fonts (including greek and cyrillic).
  * Various memory leaks and crashes.
  * And many more.
* Wed Dec 31 2014 trcs@gmx.com
- update to version 1.6
  * Features:
    + Color detection device (mudraw -T).
    + Sepia mode full-page color tinting in X11 and win32 viewer
    (keybinding: shift-C).
    + Re-implement printf and strtod due to portability issue with
    locales and number formatting.
    + Add experimental 'gsview' project: a Windows Modern UI viewer.
    + Improve XML parser interface.
  * Bug fixes:
    + CBZ page ordering
    + ZIP64 support
    + iOS and Android bug fixes
    + Miscellaneous minor fixes
* Tue Aug 26 2014 gber@opensuse.org
- update to version 1.5
  * This is a bugfix release: dozens of bugs have been found and
    exterminated!
  * A typo resulting in a potential stack overflow that could
    corrupt files when saving edits to a PDF has been fixed.
    Another bug which caused a significant slowdown has also been
    fixed.
* Fri May 30 2014 gber@opensuse.org
- fix source url
* Fri May 30 2014 gber@opensuse.org
- update to version 1.4
  * Headline changes:
  * CMYK rendering (mudraw PWG and PAM formats)
  * TIFF viewer (with multi-page support).
  * Added MuJS Javascript interpreter.
  * MuJS is the default, V8 and JavaScriptCore are compile time
    options.
  * Javascript support has to be explicitly enabled with
    pdf_enable_js.
  * All viewers now have JavaScript enabled in the default
    builds.
  * Viewers:
  * X11: Horizontal scroll wheel support.
  * X11: Status bar display with warnings.
  * Android: Digital signatures.
  * iOS: Links, form filling, annotation editing, and javascript.
  * iOS: Reflow mode.
  * WinRT: Printing.
  * WinRT: Improved zooming behaviour.
  * Tools:
  * mudraw: Banded rendering with -B /band-height/.
  * mudraw: Select output format with -F /format/.
  * mudraw: Write to stdout if you use '-' as the output file
    name.
  * mudraw: Add TGA output format.
  * mudraw: Improved SVG output.
  * mutool show: Write output to file instead of stdout with -o
    /filename/.
  * mutool clean: Clean content streams with -s option.
  * Annotations:
  * Improved font handling.
  * Form fields.
  * Free text.
  * Sticky notes.
  * Optimizations:
  * glyph cache: Partial eviction.
  * glyph cache: Run-length compressed glyphs.
  * Smarter handling of subpixel metrics in text rendering.
  * Optimized blitting functions.
  * Optimized gradient mesh drawing.
  * API changes and additions:
  * fz_stream API reworked: replace "read" function with "next".
  * "Rebind" functions to associate context bound objects with
    another context:
    fz_output, fz_stream, fz_device and fz_document.
  * Introduce "document handlers" to detect and open different
    file types.
  * Must now call fz_register_document_handlers() to register
    the defaults.
  * May register your own handlers as well to work with
    g fz_open_document.
  * Hook to load system fonts: fz_install_load_system_font_funcs.
  * PDF xref cache flushing functions (mark/clear/clear-to-mark).
  * Add our own "printf" set of functions to format strings and
    write to fz_output:
  * Format %%f as short as possible while preserving precision.
  * Has %%C for formatting a unicode character as UTF-8.
  * Has %%M to format fz_matrix.
  * Has %%R to format fz_rect.
  * Has %%q and %%( to format strings with escaped characters.
  * PDF process interface: allow PDF interpreter to do more than
    just draw!
  * Content stream state cleaning filter.
  * Content stream rewriting filter.
  * PDF digital signatures.
  * Stroke states may now be stored on the stack.
  * Improved fz_path internals.
  * Gradient mesh drawing interface has been improved.
  * Save files with incremental updates.
- drop obsolete mupdf-fix-array-overflow.patch
- switch to mujs instead of v8
* Fri Feb 14 2014 gber@opensuse.org
- add mupdf-fix-array-overflow.patch in order to fix a stack-based
  buffer overflow in xps_parse_color() (bnc#863975)
* Sat Jan  4 2014 gber@opensuse.org
- update to version 1.3
  * Windows RT viewer app for MuPDF.
  * Library changes to support progressive loading (display PDF
    files as they download). Windows/Linux/MacOS viewer supports
    this using curl.
  * Incremental updates to PDF files are now (optionally) preserved
    on loading/saving.
  * Prototype support for checking PDF Digital Signatures.
  * Initial annotation support (strike-out, underline, highlight
  and ink) (library and android builds only).
  * Fix operation on Android API level 8.
  * Android redraw optimisations.
  * Android app now supports Google Cloud Print.
  * Android app translated into many languages.
  * Android support for more architectures.
  * Improvements to store (avoid collisions causing unnecessary
    evictions).
  * Windows apps use Unicode filenames now.
  * PDF function handling improved; functions can now be passed to
    devices without 'sampling'.
  * PDF image handling improved; images can now be passed to
  devices without decompression.
  * Indexed images are no longer uncompressed at load time, saving
    memory.
  * Caching of rendered tiles for speed.
  * Improved text analysis mode, capable of spotting
    columns/indents, right-to-left text etc.
  * HTML output mode now includes image output.
  * PDF password encoding handling improved.
  * MuPDF now opens Jpeg, Tiff and PNG files directly.
  * Bug preventing OpenXPS files from being opened fixed.
  * Initial (feature incomplete) SVG and PDF output devices.
  * PWG raster (mono/grey/RGB) and PCL (mono) output devices.
  * Various performance improvements (including tilings and mesh
    based shadings).
  * Revamped directory structure to reflect recent changes.
  * Various potential SEGV, SoftMask and rendering fixes.
  * Many potential crashes in Jpeg2000 and JBIG2 images fixed.
- restore desktop file and icon which were dropped by upstream
- build with support for progressive rendering via libcurl
* Wed Jun 12 2013 dvaleev@suse.com
- set ExclusiveArch:  %%{ix86} x86_64 %%{arm}. v8 is available only
  for those architectures
* Mon Apr 29 2013 gber@opensuse.org
- fix broken setting of CFLAGS introduced by the previous change
* Sun Apr 28 2013 dap.darkness@gmail.com
- Fixed "ld: relocation R_X86_64_32 against `.rodata' can not
  be used when making a shared object; recompile with -fPIC".
* Fri Apr  5 2013 gber@opensuse.org
- update to version 1.2
  - Change licensing terms to GNU AGPL (from GNU GPL).
  - Renamed 'mubusy' to 'mutool'.
  - Add support for Javascript and forms handling.
  - PDF 1.7 Extension Level 8 encryption implemented.
  - Oversized and stroke text clipping implemented.
  - Prototype transition support.
  - Add fz_open_document_with_stream to allow non-file based
    operation.
  - Text searching API.
  - Highlight and copy text selection API.
  - Pass matrices and rectangles by reference for improved
    performance.
  - Change shadings to decompose at render times; massive memory
    savings.
  - Performance enhancements for color conversion and fax
    decompression.
  - ARM optimisations for color conversion and bitmap scaling.
  - Bitmap subsampling stage introduced, with ARM optimisations.
  - Type 3 fonts; glyphs are now handled as display lists.
  - Scan converter performance improvements.
  - Fix many SEGVs with out of spec files.
  - Various rendering fixes.
* Wed Jan 16 2013 gber@opensuse.org
- update to version 1.1
  - The command line tools have been combined into one tool that
    does all: mubusy
  - Rendering bugs fixed (text clipping, stroked text etc).
  - Better handling of 'large' (uncachable) glyphs.
  - Minor speed optimisations.
  - Shading bug fixes.
  - Move to using dynamically allocated parsing buffers (more
    resilient).
  - Support for UserUnits.
  - Fix bugs with image predictors (including with 16 bit images).
  - More resilient to out of spec files.
  - Extract pdf writing capability into the library from pdfclean,
    and expand on it to allow for linearisation. Bug fixes in the
    garbage collection of unused objects.
  - Improve pdf writing recognition of images.
  - Improved font matching.
  - Start to move away from macros to inline functions (helpful for
    applications requiring certification).
  - Many bugs fixed.
  - Removal of all global variables: we now pass a context pointer
    through the code freeing us from the use of globals within the
    library.
  - Multi-threaded operation: while MuPDF does not require a thread
    library, hooks are in place so that if one is used, significant
    speedups can be gained from using multiple cores to render.
  - New error handling: a portable exception-like system is used to
    allow neater handling of errors. This leads to more stability
    and better resilience to broken files.
  - Public/Private API: the API has undergone a significant
    revision (required by some of the above changes, plus
    renaming/revising for clarity and consistency), and has been
    split into public and private headers. The plan is that the
    public portion of the API should remain much more static in
    future.
  - Improved Text Extraction device: a cleaner API to the
    experimental text extraction device, offering a list of styles,
    and more cleanly delineated content.
  - Documentation: All public header entry points/structures are
    now documented and overviews of how to call the library to
    render pages both in single and multi-threaded mode are given.
  - A new scavenging memory manager; makes much better use of the
    memory available by freeing cached items 'just in time'.
  - Many, many, bugfixes.
- removed obsolete mupdf-use-xdg-open.patch and
  mupdf-default-resolution.patch
* Sun Jan  8 2012 gber@opensuse.org
- added mupdf-default-resolution.patch in order to change the
  default resolution to 96 DPI which should be more reasonable for
  most desktops
* Fri Dec  2 2011 gber@opensuse.org
- hide from menu since mupdf must be called with a filename
- added mupdf-use-xdg-open.patch in order to use xdg-open for
  launching a browser
* Fri Dec  2 2011 gber@opensuse.org
- initial packaging
